@@ -34,6 +34,7 @@ Sjis-JA - "Yet Another JPerl" Source code filter to escape ShiftJIS (Japanese do
       perl58   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
       perl510  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
       perl512  ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
+      perl64   ShiftJIS_script.pl  wild*  *card  and  '*quote*'  are  ok  ...
 
       ? * găChJ[h̎w肪ł܂
       ' ` ' găNH[g邱Ƃł܂
@@ -70,7 +71,7 @@ JPerl ͂ƂĂDꂽ\tgEFAłBƁAł JPerl ͓{Ήł
 Perl ̂ƂŁAJava  JVM Ƃ͊֌W܂BȂ킯ŁÃ\tgEFA
 ͏Փˉ̂߂ Sjis ƂOɂ܂B
 
-ƂŁA JPerl ̓o[W 5.005_4 ȍ~AeiXĂ܂B
+ƂŁA JPerl ̓o[W 5.005_04 ȍ~AeiXĂ܂B
 
 ώcOȂƂɁAJPerl̊Jsn  The Perl Confernce Japan
 1998 ɂ
@@ -96,14 +97,14 @@ ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
 
 =item * ShiftJIS ̂܂܂̒l
 
-=item * ߋƌ݂̃XNvgԂŃR[hAmEnELł
+=item * ߋ̃f[^AXNvgAmEnEƌ݊ۂĂ
 
 =item * UTF8 tOȂł(perlunitut  perluniadvice ̑Ή͕sv)
 
-=item * ł Perl5 Ƃ͌݊ (͂)
-
 =item * (JPerlێ炷邽߂) C vO~OsȂł
 
+=item * (CPU, OS, perl̃o[W, 32rbg/64rbgł̈Ⴂɂ) oCit@CɈˑȂ
+
 =back
 
 AJPerl ̖ɂĂЂƂ̖܂傤B
@@ -148,6 +149,7 @@ GXP[v_قȂ܂B
    perl58 make.bat install  --- perl5.008 ɃCXg[܂
    perl510 make.bat install --- perl5.010 ɃCXg[܂
    perl512 make.bat install --- perl5.012 ɃCXg[܂
+   perl64  make.bat install --- perl64    ɃCXg[܂
 
    make.bat dist            --- CPAN zzppbP[W܂
    make.bat tar.bat         --- tar.bat 쐬܂
@@ -156,9 +158,10 @@ GXP[v_قȂ܂B
 
    Sjis.pm          --- ShiftJIS \[XR[htB^W[
    Esjis.pm         --- Sjis.pm ̃^C[`
-   perl58.bat       --- ϐ PATH ̐ݒȂ perl5.8 TĎs
+   perl58.bat       --- ϐ PATH ̐ݒȂ perl5.8  TĎs
    perl510.bat      --- ϐ PATH ̐ݒȂ perl5.10 TĎs
    perl512.bat      --- ϐ PATH ̐ݒȂ perl5.12 TĎs
+   perl64.bat       --- ϐ PATH ̐ݒȂ perl64   TĎs
 
 =head1 NX̒`
 
@@ -1115,16 +1118,22 @@ zIɂ́Aȉ5̃S[悤ƍlĂ܂B
     Perl ́AoCgw Perl ƕw Perl Ɏ}ꂹɁA1̌
     葱ׂłB
 
+    JPerl  Perl 𕪊򂳂Ȃ悤ɂ邽߂ɁAC^v^𕪊򂳂܂B
+    ł Perl RA`[̓C^v^̕]łȂ̂ł傤B
+
     oCgw Perl ͂łɃoCif[^Ƃł邽߁Aw
     Perl ʗĂō쐬Kv͂܂B̃\tgEFA͒PȂ Perl ̃Av
     P[VvOłAtB^vOƂč쐬Ă܂B
     {Iɂ perl słȂΓ삷ł傤B
 
+    ɖ perl XNvgŉȂAPerl R~jeBT|[g
+    邱Ƃł傤B
+
 =item * S[5
 
     JPerl [U Perl  JPerl ێł悤ɂȂB
 
-    ԂB
+    ԂAĂƁB
 
 =back
 
@@ -1241,6 +1250,17 @@ vO~O񋟂܂B
  T1008901080816 G08901-8
  http://ascii.asciimw.jp/books/magazines/unix.shtml
 
+ ֘A\tgEFA
+ http://search.cpan.org/dist/Big5Plus/
+ http://search.cpan.org/dist/EUCJP/
+ http://search.cpan.org/dist/GB18030/
+ http://search.cpan.org/dist/HP15/
+ http://search.cpan.org/dist/INFORMIXV6ALS/
+ http://search.cpan.org/dist/Sjis/
+ http://search.cpan.org/dist/UHC/
+ http://search.cpan.org/dist/UTF2/
+ http://search.cpan.org/dist/jacode/
+
 =head1 ӎ
 
 ̃\tgEFÁAȉ̕X̍쐬\tgEFAѕ̂ɂ쐬
@@ -1282,7 +1302,7 @@ vO~O񋟂܂B
 
  n , Jperl
  http://search.cpan.org/~watanabe/
- http://mail.pm.org/pipermail/tokyo-pm/1999-September/001854.html
+ ftp://ftp.oreilly.co.jp/pcjp98/watanabe/jperlconf.ppt
 
   e, Encode W[
  http://search.cpan.org/dist/Encode/
@@ -1295,6 +1315,23 @@ vO~O񋟂܂B
 
  Tokyo-pm ۑ
  http://mail.pm.org/pipermail/tokyo-pm/
+ http://mail.pm.org/pipermail/tokyo-pm/1999-September/001844.html
+ http://mail.pm.org/pipermail/tokyo-pm/1999-September/001854.html
+
+ ruby-list
+ http://blade.nagaokaut.ac.jp/ruby/ruby-list/index.shtml
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/2440
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/2446
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/2569
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/9427
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/9431
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/10500
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/10501
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/10502
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/12385
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/12392
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/12393
+ http://blade.nagaokaut.ac.jp/cgi-bin/scat.rb/ruby/ruby-list/19156
 
 =cut
 
