@@ -1,31 +1,33 @@
 use Sjis;
 
+my $__FILE__ = __FILE__;
+
 $text = 'hnDrxrFQQTTTWFXT|PO|ORF||F';
 
 # 7.7 splitZq(XgReLXg)
 @_ = split(/F/, $text);
 if (join('', map {"($_)"} @_) eq "(hnDrxr)(QQTTTW)(XT|PO|OR)(||)()") {
-    print qq{ok - 1 \@_ = split(/F/, \$text);\n};
+    print qq{ok - 1 \@_ = split(/F/, \$text); $^X $__FILE__\n};
 }
 else {
-    print qq{not ok - 1 \@_ = split(/F/, \$text);\n};
+    print qq{not ok - 1 \@_ = split(/F/, \$text); $^X $__FILE__\n};
 }
 
 # 7.7 splitZq(XJReLXg)
 $a = split(/F/, $text);
 if (join('', map {"($_)"} @_) eq "(hnDrxr)(QQTTTW)(XT|PO|OR)(||)()") {
-    print qq{ok - 2 \$a = split(/F/, \$text);\n};
+    print qq{ok - 2 \$a = split(/F/, \$text); $^X $__FILE__\n};
 }
 else {
-    print qq{not ok - 2 \$a = split(/F/, \$text);\n};
+    print qq{not ok - 2 \$a = split(/F/, \$text); $^X $__FILE__\n};
 }
 
 # 7.7 splitZq(voidReLXg)
 split(/F/, $text);
 if (join('', map {"($_)"} @_) eq "(hnDrxr)(QQTTTW)(XT|PO|OR)(||)()") {
-    print qq{ok - 3 (void) split(/F/, \$text);\n};
+    print qq{ok - 3 (void) split(/F/, \$text); $^X $__FILE__\n};
 }
 else {
-    print qq{not ok - 3 (void) split(/F/, \$text);\n};
+    print qq{not ok - 3 (void) split(/F/, \$text); $^X $__FILE__\n};
 }
 
